# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2023-2024, by Samuel Williams.

require_relative "bound_endpoint"
require_relative "connected_endpoint"
